@@ -1,8 +1,9 @@
 # Copyright (C) 2009, 2010 Robert Lehmann
 
-__version__ = "1.1"
+__version__ = "1.2"
 
 from libleipzig.protocol import *
 from libleipzig.transport import services
+from suds import WebFault
 
-__all__ = services.keys()
+__all__ = services.keys() + ['WebFault']
