@@ -29,7 +29,11 @@ def service(*results):
             setattr(Result, typ, property(operator.itemgetter(n)))
         Result.__name__ = "%sResult" % name
 
-        def get_client(func, name):
+        def get_client(func, name, cred=None):
+            if cred:
+                return suds.client.Client(BASEURL % name,
+                    transport=suds.transport.http.HttpAuthenticated(
+                        username=cred[0], password=cred[1]))
             if not hasattr(func, '_client'):
                 func._client = client = suds.client.Client(BASEURL % name,
                         transport=auth)
@@ -37,9 +41,9 @@ def service(*results):
             return func._client
 
         @functools.wraps(f)
-        def func(*vectors):
+        def func(*vectors, **options):
             # this prefetches the WSDL on library load!
-            client = get_client(func, name)
+            client = get_client(func, name, options.pop('auth', None))
 
             if len(args) != len(vectors):
                 raise TypeError(
@@ -48,7 +52,11 @@ def service(*results):
 
             # assemble query to the SOAP service
             request = client.factory.create('RequestParameter')
-            request.corpus = 'de'
+            request.corpus = options.pop('corpus', 'de')
+
+            if options:
+                raise TypeError("%s() got an unexpected option '%s'" %
+                    (name, iter(options).next()))
 
             for key, value in zip(args, vectors):
                 vector = client.factory.create('ns0:DataVector')
@@ -77,6 +85,10 @@ def service(*results):
         func.__doc__ = "%s(%s) -> %s\n" % (name, ", ".join(args),
             ", ".join(results)) + func._doc
         func.prefetch = lambda: get_client(func, name)
+        func.set_credentials = lambda username, password: (
+                get_client(func, name).set_options(
+                    transport=suds.transport.http.HttpAuthenticated(
+                        username=username, password=password)))
         services[name] = func
 
         return func
